@@ -183,14 +183,7 @@ main (int argc, char *argv[])
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-#if !GLIB_CHECK_VERSION(2,32,0)
-	if (! g_thread_supported ())
-		g_thread_init (NULL);
-#endif
 	dbus_g_thread_init ();
-#if !GLIB_CHECK_VERSION(2,36,0)
-	g_type_init ();
-#endif
 
 	context = g_option_context_new (N_("MATE Power Manager"));
 	/* TRANSLATORS: program name, a simple app to view pending updates */
@@ -204,10 +197,6 @@ main (int argc, char *argv[])
 		goto unref_program;
 	}
 
-#if !GLIB_CHECK_VERSION(2,32,0)
-	if (!g_thread_supported ())
-		g_thread_init (NULL);
-#endif
 	dbus_g_thread_init ();
 
 	gtk_init (&argc, &argv);
@@ -254,7 +243,7 @@ main (int argc, char *argv[])
 
 	if (!gpm_object_register (session_connection, G_OBJECT (manager))) {
 		egg_error ("%s is already running in this session.", GPM_NAME);
-		return 0;
+		goto unref_program;
 	}
 
 	/* register to be a policy agent, just like kpackagekit does */
